dae-deprecated: Deprecated Functions in Package dae
Description
These functions have been renamed and deprecated in dae.
Usage
blockboundary.plot(...)
design.plot(...)
proj2.decomp(...)
proj2.ops(...)
projs.canon(...)
projs.structure(...)
Arguments
...
absorbs arguments passed from the old functions of the style foo.bar().